<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class DailydevotationsController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'The 24X7 GOD :: Manage Dailydevotation';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => [
                'Dailydevotations.created' => 'DESC'
            ],
        ];        
        $keyword = $this->request->query('keyword');
		$condition = [];
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Dailydevotations.name LIKE '%".$keyword."%'"],
					["Dailydevotations.files LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Dailydevotations->find('all')->where($condition);       
        $dailydevotations = $this->paginate($query);
        $dailydevotations = $dailydevotations->toArray();
		//pr($dailydevotations);die;
        $this->set(compact('dailydevotations', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'The 24X7 GOD ::  Add New Dailydevotation';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		
		
        $dailydevotations = $this->Dailydevotations->newEntity();        
       
        if ($this->request->is('post')) {
            $userImage = @$this->request->data['files'];	
			unset($this->request->data['files']);			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$this->request->data['files'] = $filename;
			}
			$dailydevotations = $this->Dailydevotations->patchEntity($dailydevotations, $this->request->data, ['validate' => 'customer']);            
			$dailydevotations['created'] = date('Y-m-d H:i:s');
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Dailydevotations->save($dailydevotations)) {
				if(!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/devolation/';	                    
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('Dailydevotation added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new dailydevotation, Please try again later.'));
			}
		}
        $this->set(compact('dailydevotations','client_list'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'The 24X7 GOD :: Edit Dailydevotation';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
        $dailydevotations = $this->Dailydevotations->find()->where(['Dailydevotations.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {
			$userImage = $this->request->data['files'];	
			unset($this->request->data['files']);
			
			$old_data = $this->Dailydevotations->get($id);            			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$dailydevotations['files'] = $filename;
				$this->request->data['files'] = $filename;
			}
			
			$dailydevotations = $this->Dailydevotations->patchEntity($dailydevotations, $this->request->data, ['validate' => 'customer']);
			
			
			$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Dailydevotations->save($dailydevotations)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/devolation/';	
					@unlink(WWW_ROOT . 'img/uploads/devolation/'.$old_data->image);
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
					
				}
				$this->Flash->success(__('The dailydevotation updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Dailydevotation information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('dailydevotations'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Dailydevotations->get($id);
        if ($this->Dailydevotations->delete($users)) {
            $this->Flash->success(__('Dailydevotation has been deleted.'));
        } else {
            $this->Flash->error(__('Dailydevotation could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Dailydevotations', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Dailydevotations->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Dailydevotations');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Dailydevotation has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Dailydevotations', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'The 24X7 GOD ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Dailydevotations->find()->where(['Dailydevotations.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Dailydevotations', 'action' => 'index']);
        }
	}
	
	
}