<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class EventsController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'The 24X7 GOD :: Manage Event';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => [
                'Events.created' => 'DESC'
            ],
			'contain' => ['Users'],
        ];        
        $keyword = $this->request->query('keyword');
		$condition = [];
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Events.name LIKE '%".$keyword."%'"],
					["Events.location LIKE '%".$keyword."%'"],
					["Events.eventDate LIKE '%".$keyword."%'"],
					["Events.eventTime LIKE '%".$keyword."%'"],
					["Events.description LIKE '%".$keyword."%'"],
					["Events.eventCapacity LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Events->find('all')->where($condition);       
        $events = $this->paginate($query);
        $events = $events->toArray();
		//pr($events);die;
        $this->set(compact('events', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'The 24X7 GOD ::  Add New Event';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		$this->loadModel('Categories');
//		$categoryList = $this->Categories->find('list', ['keyField' => 'id', 'valueField' => ['name']])
//						->where(['Categories.status'=>1])
//                        ->order(['Categories.name'=>'ASC'])->toArray(); 
//		$this->loadModel('Users');
//		$userList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName']])
//						->where(['Users.status'=>1])
//                        ->order(['Users.fullName'=>'ASC'])->toArray();
						
        $events = $this->Events->newEntity();        
       
        if ($this->request->is('post')) {
            
			$userImage = @$this->request->data['image'];	
			unset($this->request->data['image']);			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$this->request->data['image'] = $filename;
			}
			
			$events = $this->Events->patchEntity($events, $this->request->data, ['validate' => 'customer']);            
			$events['created'] = date('Y-m-d H:i:s');
			$events['eventDate'] = $this->request->data['eventDate'];
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Events->save($events)) {
				if(!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/event/';	                    
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('Event added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new event, Please try again later.'));
			}
		}
        $this->set(compact('events','categoryList', 'userList'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'The 24X7 GOD :: Edit Event';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
//		$this->loadModel('Categories');
//		$categoryList = $this->Categories->find('list', ['keyField' => 'id', 'valueField' => ['name']])
//						->where(['Categories.status'=>1])
//                        ->order(['Categories.name'=>'ASC'])->toArray();
//		
//		$this->loadModel('Users');
//		$userList = $this->Users->find('list', ['keyField' => 'id', 'valueField' => ['fullName']])
//						->where(['Users.status'=>1])
//                        ->order(['Users.fullName'=>'ASC'])->toArray();

        $events = $this->Events->find()->where(['Events.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {
			
			$userImage = $this->request->data['image'];	
			unset($this->request->data['image']);
			
			$old_data = $this->Events->get($id);            			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$categories['image'] = $filename;
				$this->request->data['image'] = $filename;
			}
			$events = $this->Events->patchEntity($events, $this->request->data, ['validate' => 'customer']);
			
			
			$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Events->save($events)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/event/';	
					@unlink(WWW_ROOT . 'img/uploads/event/'.$old_data->image);
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
					
				}
				$this->Flash->success(__('The event updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Event information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('events', 'categoryList', 'userList'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Events->get($id);
        if ($this->Events->delete($users)) {
            $this->Flash->success(__('Event has been deleted.'));
        } else {
            $this->Flash->error(__('Event could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Events', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Events->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Events');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Event has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Events', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'The 24X7 GOD ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Events->find()->where(['Events.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Events', 'action' => 'index']);
        }
	}
	
	
}