<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class JobsController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'The 24X7 GOD :: Manage Job';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => [
                'Jobs.created' => 'DESC'
            ],
        ];        
        $keyword = $this->request->query('keyword');
		$condition = [];
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Jobs.jobName LIKE '%".$keyword."%'"],
					["Jobs.churchName LIKE '%".$keyword."%'"],
					["Jobs.loacation LIKE '%".$keyword."%'"],
					["Jobs.phone LIKE '%".$keyword."%'"],
					["Jobs.email LIKE '%".$keyword."%'"],
					["Jobs.about LIKE '%".$keyword."%'"],
					["Jobs.publishDate LIKE '%".$keyword."%'"],
					["Jobs.applyBy LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Jobs->find('all')->where($condition);       
        $jobs = $this->paginate($query);
        $jobs = $jobs->toArray();
		//pr($jobs);die;
        $this->set(compact('jobs', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'The 24X7 GOD ::  Add New Job';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		
		
        $jobs = $this->Jobs->newEntity();        
       
        if ($this->request->is('post')) {
            
			$userImage = $this->request->data['image'];	
			unset($this->request->data['image']);			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				//$users['profile_picture'] = $filename;
				$this->request->data['image'] = $filename;
			}
			
			$jobs = $this->Jobs->patchEntity($jobs, $this->request->data, ['validate' => 'customer']);            
			$jobs['created'] = date('Y-m-d H:i:s');
			$jobs['publishDate'] = date('Y-m-d',strtotime($this->request->data['publishDate']));
			$jobs['applyBy'] = date('Y-m-d',strtotime($this->request->data['publishDate']));
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Jobs->save($jobs)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/jobs/';	                    
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('Job added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new job, Please try again later.'));
			}
		}
        $this->set(compact('jobs','client_list'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'The 24X7 GOD :: Edit Job';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
        $jobs = $this->Jobs->find()->where(['Jobs.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {
			
			$userImage = $this->request->data['image'];	
			unset($this->request->data['image']);
			
			$old_data = $this->Jobs->get($id);            			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$this->request->data['image'] = $filename;
			}
			if(!empty($filename)){				
				$oldfilename = $old_data->image;
			}	
			$jobs = $this->Jobs->patchEntity($jobs, $this->request->data, ['validate' => 'customer']);
			$jobs['publishDate'] = date('Y-m-d',strtotime($this->request->data['publishDate']));
			$jobs['applyBy'] = date('Y-m-d',strtotime($this->request->data['publishDate']));
			
			$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Jobs->save($jobs)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/jobs/';	
					@unlink(WWW_ROOT . 'img/uploads/jobs/'.$oldfilename);
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('The job updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Job information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('jobs'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Jobs->get($id);
        if ($this->Jobs->delete($users)) {
            $this->Flash->success(__('Job has been deleted.'));
        } else {
            $this->Flash->error(__('Job could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Jobs', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Jobs->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Jobs');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Job has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Jobs', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'The 24X7 GOD ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Jobs->find()->where(['Jobs.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Jobs', 'action' => 'index']);
        }
	}
	
	
}